import os
import random


########################################################################################
#
#######################################################################################
class SiRandom:
        
    ########################################################################################
    #
    #######################################################################################
    @staticmethod
    def Seed(seed):

        #seed 0 means use random based on system time 
        #python does this by default - so no need to do anything
        if seed == 0:
            return

        random.seed(seed)


    ########################################################################################
    #
    # return [0.0 to 1.0)
    #
    #######################################################################################
    @staticmethod
    def GetFloat():
        return random.random()


    ########################################################################################
    #
    # return [0.0 to 1.0]
    #
    #######################################################################################
    @staticmethod
    def GetInt(min, max):
        return random.randint(min, max)

    ########################################################################################
    #
    #######################################################################################
    @staticmethod
    def GetTrueFalse():
        if SiRandom.GetInt(0,1) == 0:
            return False

        return True

